// DSPDoc.h : interface of the CDSPDoc class
//
/////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_DSPDOC_H__35DE45AA_DE56_11D4_B5EF_5254AB134FE2__INCLUDED_)
#define AFX_DSPDOC_H__35DE45AA_DE56_11D4_B5EF_5254AB134FE2__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "ConvertDlg.h"
#include "LopassDlg.h"
#include "HipassDlg.h"
#include "BandpassDlg.h"
#include "BandrejectDlg.h"
#include "UserfilterDlg.h"
#include "MovingavgDlg.h"
#include "ChebyshevDlg.h"
#include "EchoDlg.h"
#include "AmpmodDlg.h"
#include "ConvolDlg.h"
#include "HomomorphicDlg.h"
#include "IIRDlg.h"
#include "NewDocDlg.h"
#include "RecordDlg.h"
#include "3DDesignDlg.h"
#include "SetSampleDlg.h"
#include "AddNoiseDlg.h"
#include "FadeDlg.h"
#include "PitchShiftDlg.h"
#include "ChorusDlg.h"
#include "ReverbDlg.h"

class CDSPDoc : public CDocument
{
private:
	void DeleteSelection();
	int GetSampleSize();
	int GetSamples();
	void Play(int StartPos, int EndPos);
	CConvertDlg dlg;
	CNewDocDlg newdoc;
	CLopassDlg lopass;
	CHipassDlg hipass;
	CBandpassDlg bandpass;
	CBandrejectDlg bandreject;
	CUserfilterDlg userfir;
	CRecordDlg recdlg;
	CEchoDlg echodlg;
	CAmpmodDlg ampdlg;
	CConvolDlg condlg;
	CHomomorphicDlg homodlg;
	CIIRDlg iirdlg;
	CMovingavgDlg avgdlg;
	CChebyshevDlg chdlg;
	C3DDesignDlg dlg3d;
	CSetSampleDlg smpdlg;
	CAddNoiseDlg noisedlg;
	CFadeDlg fadedlg;
	CPitchShiftDlg pitchdlg;
	CChorusDlg chorusdlg;
	CReverbDlg reverbdlg;
	CDialog d;
	friend class CHomomorphicDlg;
	friend void CALLBACK waveOutProc(HWAVEOUT hwo,	UINT uMsg, DWORD dwInstance,
									 DWORD dwParam1, DWORD dwParam2);
	void EnableMenuItems(UINT enable);
	int m_Freq;
	int m_NumDevs;
	void ApplyFilter(int type, bool IsFIR, bool Show, bool Apply);
	void ModSynth(bool IsSynth);
protected: // create from serialization only
	CDSPDoc();
	DECLARE_DYNCREATE(CDSPDoc)

// Attributes
public:
	HWAVEOUT hwo;
	HWAVEIN hwi;
	int StartPos;
	int EndPos;
	WaveHeader h;
	bool IsPlaying;
	bool Paused;
	char *data;
	bool CheckFormat(WaveHeader h);
// Operations
public:

// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CDSPDoc)
	public:
	virtual BOOL OnNewDocument();
	virtual void Serialize(CArchive& ar);
	virtual BOOL OnOpenDocument(LPCTSTR lpszPathName);
	virtual BOOL OnSaveDocument(LPCTSTR lpszPathName);
	virtual BOOL OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO* pHandlerInfo);
	//}}AFX_VIRTUAL
	virtual void DeleteContents();
// Implementation
public:
	virtual ~CDSPDoc();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

protected:

// Generated message map functions
protected:
	//{{AFX_MSG(CDSPDoc)
	afx_msg void OnConvert();
	afx_msg void OnEditCopy();
	afx_msg void OnEditPaste();
	afx_msg void OnEditCut();
	afx_msg void OnEditClear();
	afx_msg void OnFileinfo();
	afx_msg void OnPlay();
	afx_msg void OnUpdateFileNew(CCmdUI* pCmdUI);
	afx_msg void OnUpdateFileOpen(CCmdUI* pCmdUI);
	afx_msg void OnUpdateFileSave(CCmdUI* pCmdUI);
	afx_msg void OnUpdateFileSaveAs(CCmdUI* pCmdUI);
	afx_msg void OnUpdateConvert(CCmdUI* pCmdUI);
	afx_msg void OnUpdateStop(CCmdUI* pCmdUI);
	afx_msg void OnPlayall();
	afx_msg void OnUpdatePlay(CCmdUI* pCmdUI);
	afx_msg void OnUpdatePlayall(CCmdUI* pCmdUI);
	afx_msg void OnUpdatePause(CCmdUI* pCmdUI);
	afx_msg void OnStop();
	afx_msg void OnUpdateRewind(CCmdUI* pCmdUI);
	afx_msg void OnUpdateForward(CCmdUI* pCmdUI);
	afx_msg void OnUpdateGotoend(CCmdUI* pCmdUI);
	afx_msg void OnUpdateGotostart(CCmdUI* pCmdUI);
	afx_msg void OnPause();
	afx_msg void OnUpdateAppAbout(CCmdUI* pCmdUI);
	afx_msg void OnUpdateFileinfo(CCmdUI* pCmdUI);
	afx_msg void OnPlayparams();
	afx_msg void OnUpdatePlayparams(CCmdUI* pCmdUI);
	afx_msg void OnUpdateLopass(CCmdUI* pCmdUI);
	afx_msg void OnLopass();
	afx_msg void OnHipass();
	afx_msg void OnUpdateHipass(CCmdUI* pCmdUI);
	afx_msg void OnUpdateBandpass(CCmdUI* pCmdUI);
	afx_msg void OnBandpass();
	afx_msg void OnBandreject();
	afx_msg void OnUpdateBandreject(CCmdUI* pCmdUI);
	afx_msg void OnUpdateUserfir(CCmdUI* pCmdUI);
	afx_msg void OnUserfir();
	afx_msg void OnClear();
	afx_msg void OnFileRecord();
	afx_msg void OnUpdateRemovedc(CCmdUI* pCmdUI);
	afx_msg void OnRemovedc();
	afx_msg void OnMovingavg();
	afx_msg void OnUpdateMovingavg(CCmdUI* pCmdUI);
	afx_msg void OnUpdateChebyshev(CCmdUI* pCmdUI);
	afx_msg void OnChebyshev();
	afx_msg void OnUpdateEcho(CCmdUI* pCmdUI);
	afx_msg void OnEcho();
	afx_msg void OnUpdateAmpmod(CCmdUI* pCmdUI);
	afx_msg void OnAmpmod();
	afx_msg void OnUpdateConvolution(CCmdUI* pCmdUI);
	afx_msg void OnConvolution();
	afx_msg void OnUpdateLogarithming(CCmdUI* pCmdUI);
	afx_msg void OnLogarithming();
	afx_msg void OnUpdateFourier(CCmdUI* pCmdUI);
	afx_msg void OnFourier();
	afx_msg void OnUpdateIirdesign(CCmdUI* pCmdUI);
	afx_msg void OnIirdesign();
	afx_msg void OnUpdate3ddesign(CCmdUI* pCmdUI);
	afx_msg void On3ddesign();
	afx_msg void OnUpdateSynth(CCmdUI* pCmdUI);
	afx_msg void OnSynth();
	afx_msg void OnUpdateSetsamples(CCmdUI* pCmdUI);
	afx_msg void OnSetsamples();
	afx_msg void OnUpdateAddnoise(CCmdUI* pCmdUI);
	afx_msg void OnAddnoise();
	afx_msg void OnUpdateFade(CCmdUI* pCmdUI);
	afx_msg void OnFade();
	afx_msg void OnUpdatePitchshift(CCmdUI* pCmdUI);
	afx_msg void OnPitchshift();
	afx_msg void OnUpdateChorus(CCmdUI* pCmdUI);
	afx_msg void OnChorus();
	afx_msg void OnUpdateReverb(CCmdUI* pCmdUI);
	afx_msg void OnReverb();
	afx_msg void OnUpdateReverse(CCmdUI* pCmdUI);
	afx_msg void OnReverse();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_DSPDOC_H__35DE45AA_DE56_11D4_B5EF_5254AB134FE2__INCLUDED_)
