// DSPView.h : interface of the CDSPView class
//
/////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_DSPVIEW_H__35DE45AC_DE56_11D4_B5EF_5254AB134FE2__INCLUDED_)
#define AFX_DSPVIEW_H__35DE45AC_DE56_11D4_B5EF_5254AB134FE2__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#define C_HEIGHT	256
#define FORMAT_STR  "DSP document"
#define S_WIDTH     40
#define S_HEIGHT    20
#define TICKS		16

#include "SelectDlg.h"

class CDSPView : public CView
{
private:
	BOOL m_IsLinear;
	int m_Scale;
	int m_OldScale;
	int m_Form;
	int m_nChannels;
	int m_StepSize;
	int m_PageSize;
	int m_Pos;
	int m_Control;
	int m_Pressed;
	int m_IncTime;
	int m_PlayPos;
	CFont m_ScaleFnt;
	CPen m_DarkPen, m_FacePen, m_LightPen, m_GrayPen[256], m_BluePen;
	CBrush m_FaceBrush;
	void UpdateCaret(CDC *pDC);
	void UpdateScale();
	void UpdatePosition();
	void UpdateParameters(CDSPDoc *pDoc);
	void DrawChannel_0(CDC *pDC, CRect r, int Is16bit, int IsRight, int N, int Y, char *data);
	void DrawChannel_1(CDC *pDC, CRect r, int Is16bit, int IsRight, int N, int Y, char *data);
	void DrawChannel_2(CDC *pDC, CRect r, int Is16bit, int IsRight, int N, int Y, char *data);
	void GetSampleTime(int nSample, char *time);
	int GetSampleTime(int Sample);
	int GetSampleSize();
	void GetTimeString(int msecs, char *time);
	void CheckPosition();
	void DeleteSelection();
	void GetClientRect(LPRECT lpRect);
	void DrawHorzScale(CDC *pDC);
	void DrawVertScale(CDC *pDC, int y1, int y2, int y3);
	void CalcIncTime();
	int GetSampleForTime(int msecs);
	CStatusBar *pStatus;
	CSelectDlg seldlg;
protected: // create from serialization only
	CDSPView();
	DECLARE_DYNCREATE(CDSPView)

// Attributes
public:
	CDSPDoc* GetDocument();

// Operations
public:
	int m_StartPos;
	int m_EndPos;
	int m_nSamples;
	int GetSelectionSize();
	int GetStartPos();
	int GetEndPos();
	void UpdateScrollParams();

// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CDSPView)
	public:
	virtual void OnDraw(CDC* pDC);  // overridden to draw this view
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	protected:
	virtual void OnUpdate(CView* pSender, LPARAM lHint, CObject* pHint);
	virtual void OnActivateView(BOOL bActivate, CView* pActivateView, CView* pDeactiveView);
	//}}AFX_VIRTUAL

// Implementation
public:
	virtual ~CDSPView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

protected:

// Generated message map functions
protected:
	//{{AFX_MSG(CDSPView)
	afx_msg void OnLinear();
	afx_msg void OnUpdateLinear(CCmdUI* pCmdUI);
	afx_msg void OnLogarithmic();
	afx_msg void OnUpdateLogarithmic(CCmdUI* pCmdUI);
	afx_msg void OnZoomin();
	afx_msg void OnZoomout();
	afx_msg void OnSamples();
	afx_msg void OnUpdateSamples(CCmdUI* pCmdUI);
	afx_msg void OnSpectrogram();
	afx_msg void OnUpdateSpectrogram(CCmdUI* pCmdUI);
	afx_msg void OnHistogram();
	afx_msg void OnUpdateHistogram(CCmdUI* pCmdUI);
	afx_msg void OnUpdateZoomin(CCmdUI* pCmdUI);
	afx_msg void OnUpdateZoomout(CCmdUI* pCmdUI);
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnHScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar);
	afx_msg BOOL OnEraseBkgnd(CDC* pDC);
	afx_msg void OnVScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar);
	afx_msg void OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnKeyUp(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg BOOL OnSetCursor(CWnd* pWnd, UINT nHitTest, UINT message);
	afx_msg void OnLButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnLButtonUp(UINT nFlags, CPoint point);
	afx_msg void OnMouseMove(UINT nFlags, CPoint point);
	afx_msg void OnTimer(UINT nIDEvent);
	afx_msg void OnUpdateEditCopy(CCmdUI* pCmdUI);
	afx_msg void OnUpdateEditCut(CCmdUI* pCmdUI);
	afx_msg void OnUpdateEditClear(CCmdUI* pCmdUI);
	afx_msg void OnUpdateEditPaste(CCmdUI* pCmdUI);
	afx_msg void OnGotoend();
	afx_msg void OnGotostart();
	afx_msg void OnForward();
	afx_msg void OnRewind();
	afx_msg void OnUpdateClear(CCmdUI* pCmdUI);
	afx_msg void OnSelectall();
	afx_msg void OnSelfragment();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

#ifndef _DEBUG  // debug version in DSPView.cpp
inline CDSPDoc* CDSPView::GetDocument()
   { return (CDSPDoc*)m_pDocument; }
#endif

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_DSPVIEW_H__35DE45AC_DE56_11D4_B5EF_5254AB134FE2__INCLUDED_)
